==> zio-aws-codebuild_2.12-5.17.102.7-sources.jar: zio/aws/codebuild/model/CreateWebhookRequest.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.codebuild.model.primitives.ProjectName
import scala.jdk.CollectionConverters._
final case class CreateWebhookRequest(
    projectName: ProjectName,
    branchFilter: Option[String] = None,
    filterGroups: Option[
      Iterable[Iterable[zio.aws.codebuild.model.WebhookFilter]]
    ] = None,
    buildType: Option[zio.aws.codebuild.model.WebhookBuildType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.CreateWebhookRequest = {
    import CreateWebhookRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.CreateWebhookRequest
      .builder()
      .projectName(ProjectName.unwrap(projectName): java.lang.String)
      .optionallyWith(branchFilter.map(value => value: java.lang.String))(
        _.branchFilter
      )
      .optionallyWith(
        filterGroups.map(value =>
          value.map { item =>
            item.map { item =>
              item.buildAwsValue()
            }.asJavaCollection
          }.asJavaCollection
        )
      )(_.filterGroups)
      .optionallyWith(buildType.map(value => value.unwrap))(_.buildType)
      .build()
  }
  def asReadOnly: zio.aws.codebuild.model.CreateWebhookRequest.ReadOnly =
    zio.aws.codebuild.model.CreateWebhookRequest.wrap(buildAwsValue())
}
object CreateWebhookRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.CreateWebhookRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.CreateWebhookRequest =
      zio.aws.codebuild.model.CreateWebhookRequest(
        projectName,
        branchFilter.map(value => value),
        filterGroups.map(value =>
          value.map { item =>
            item.map { item =>
              item.asEditable
            }
          }
        ),
        buildType.map(value => value)
      )
    def projectName: ProjectName
    def branchFilter: Option[String]
    def filterGroups
        : Option[List[List[zio.aws.codebuild.model.WebhookFilter.ReadOnly]]]
    def buildType: Option[zio.aws.codebuild.model.WebhookBuildType]
    def getProjectName: ZIO[Any, Nothing, ProjectName] =
      ZIO.succeed(projectName)
    def getBranchFilter: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("branchFilter", branchFilter)
    def getFilterGroups: ZIO[Any, AwsError, List[
      List[zio.aws.codebuild.model.WebhookFilter.ReadOnly]
    ]] = AwsError.unwrapOptionField("filterGroups", filterGroups)
    def getBuildType
        : ZIO[Any, AwsError, zio.aws.codebuild.model.WebhookBuildType] =
      AwsError.unwrapOptionField("buildType", buildType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.CreateWebhookRequest
  ) extends zio.aws.codebuild.model.CreateWebhookRequest.ReadOnly {
    override val projectName: ProjectName =
      zio.aws.codebuild.model.primitives.ProjectName(impl.projectName())
    override val branchFilter: Option[String] =
      scala.Option(impl.branchFilter()).map(value => value: String)
    override val filterGroups
        : Option[List[List[zio.aws.codebuild.model.WebhookFilter.ReadOnly]]] =
      scala
        .Option(impl.filterGroups())
        .map(value =>
          value.asScala.map { item =>
            item.asScala.map { item =>
              zio.aws.codebuild.model.WebhookFilter.wrap(item)
            }.toList
          }.toList
        )
    override val buildType: Option[zio.aws.codebuild.model.WebhookBuildType] =
      scala
        .Option(impl.buildType())
        .map(value => zio.aws.codebuild.model.WebhookBuildType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.CreateWebhookRequest
  ): zio.aws.codebuild.model.CreateWebhookRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-codebuild_2.13-5.17.224.4-sources.jar: zio/aws/codebuild/model/CreateWebhookRequest.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.codebuild.model.primitives.ProjectName
import scala.jdk.CollectionConverters._
final case class CreateWebhookRequest(
    projectName: ProjectName,
    branchFilter: Optional[String] = Optional.Absent,
    filterGroups: Optional[
      Iterable[Iterable[zio.aws.codebuild.model.WebhookFilter]]
    ] = Optional.Absent,
    buildType: Optional[zio.aws.codebuild.model.WebhookBuildType] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.CreateWebhookRequest = {
    import CreateWebhookRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.CreateWebhookRequest
      .builder()
      .projectName(ProjectName.unwrap(projectName): java.lang.String)
      .optionallyWith(branchFilter.map(value => value: java.lang.String))(
        _.branchFilter
      )
      .optionallyWith(
        filterGroups.map(value =>
          value.map { item =>
            item.map { item =>
              item.buildAwsValue()
            }.asJavaCollection
          }.asJavaCollection
        )
      )(_.filterGroups)
      .optionallyWith(buildType.map(value => value.unwrap))(_.buildType)
      .build()
  }
  def asReadOnly: zio.aws.codebuild.model.CreateWebhookRequest.ReadOnly =
    zio.aws.codebuild.model.CreateWebhookRequest.wrap(buildAwsValue())
}
object CreateWebhookRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.CreateWebhookRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.CreateWebhookRequest =
      zio.aws.codebuild.model.CreateWebhookRequest(
        projectName,
        branchFilter.map(value => value),
        filterGroups.map(value =>
          value.map { item =>
            item.map { item =>
              item.asEditable
            }
          }
        ),
        buildType.map(value => value)
      )
    def projectName: ProjectName
    def branchFilter: Optional[String]
    def filterGroups
        : Optional[List[List[zio.aws.codebuild.model.WebhookFilter.ReadOnly]]]
    def buildType: Optional[zio.aws.codebuild.model.WebhookBuildType]
    def getProjectName: ZIO[Any, Nothing, ProjectName] =
      ZIO.succeed(projectName)
    def getBranchFilter: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("branchFilter", branchFilter)
    def getFilterGroups: ZIO[Any, AwsError, List[
      List[zio.aws.codebuild.model.WebhookFilter.ReadOnly]
    ]] = AwsError.unwrapOptionField("filterGroups", filterGroups)
    def getBuildType
        : ZIO[Any, AwsError, zio.aws.codebuild.model.WebhookBuildType] =
      AwsError.unwrapOptionField("buildType", buildType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.CreateWebhookRequest
  ) extends zio.aws.codebuild.model.CreateWebhookRequest.ReadOnly {
    override val projectName: ProjectName =
      zio.aws.codebuild.model.primitives.ProjectName(impl.projectName())
    override val branchFilter: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.branchFilter())
      .map(value => value: String)
    override val filterGroups
        : Optional[List[List[zio.aws.codebuild.model.WebhookFilter.ReadOnly]]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filterGroups())
        .map(value =>
          value.asScala.map { item =>
            item.asScala.map { item =>
              zio.aws.codebuild.model.WebhookFilter.wrap(item)
            }.toList
          }.toList
        )
    override val buildType: Optional[zio.aws.codebuild.model.WebhookBuildType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.buildType())
        .map(value => zio.aws.codebuild.model.WebhookBuildType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.CreateWebhookRequest
  ): zio.aws.codebuild.model.CreateWebhookRequest.ReadOnly = new Wrapper(impl)
}
